summaryrefslogtreecommitdiff
path: root/src/Simplex_tree/test
diff options
context:
space:
mode:
authorvrouvrea <vrouvrea@636b058d-ea47-450e-bf9e-a15bfbe3eedb>2017-10-20 08:24:03 +0000
committervrouvrea <vrouvrea@636b058d-ea47-450e-bf9e-a15bfbe3eedb>2017-10-20 08:24:03 +0000
commit6fff7c1774365f99c93d57bdf3595e6b89f16b0a (patch)
treefeea01abd8e59959714e3ece6ba8aaebb0c098c0 /src/Simplex_tree/test
parente36dafedbab909ef1d16eceb133cd8b80dd1763d (diff)
Code review : rename automatic_dimension_set with downgrade_dimension
git-svn-id: svn+ssh://scm.gforge.inria.fr/svnroot/gudhi/branches/ST_automatic_dimension_set@2796 636b058d-ea47-450e-bf9e-a15bfbe3eedb Former-commit-id: 3b094bc579367d40790c3791f2c4a3700a3d93ae
Diffstat (limited to 'src/Simplex_tree/test')
-rw-r--r--src/Simplex_tree/test/simplex_tree_remove_unit_test.cpp20
1 files changed, 10 insertions, 10 deletions
diff --git a/src/Simplex_tree/test/simplex_tree_remove_unit_test.cpp b/src/Simplex_tree/test/simplex_tree_remove_unit_test.cpp
index 87c77801..747e7eeb 100644
--- a/src/Simplex_tree/test/simplex_tree_remove_unit_test.cpp
+++ b/src/Simplex_tree/test/simplex_tree_remove_unit_test.cpp
@@ -112,7 +112,7 @@ BOOST_AUTO_TEST_CASE(remove_maximal_simplex) {
std::cout << "st.dimension()=" << st.dimension() << std::endl;
BOOST_CHECK(st.dimension() == 3);
- st.automatic_dimension_set();
+ st.downgrade_dimension();
std::cout << "st.dimension()=" << st.dimension() << " | st_wo_seven.dimension()=" << st_wo_seven.dimension() << std::endl;
BOOST_CHECK(st == st_wo_seven);
@@ -152,7 +152,7 @@ BOOST_AUTO_TEST_CASE(auto_dimension_set) {
st.remove_maximal_simplex(st.find({1, 2, 3, 5}));
std::cout << "st.dimension()=" << st.dimension() << std::endl;
BOOST_CHECK(st.dimension() == 3);
- st.automatic_dimension_set();
+ st.downgrade_dimension();
std::cout << "st.dimension()=" << st.dimension() << std::endl;
BOOST_CHECK(st.dimension() == 2);
@@ -175,7 +175,7 @@ BOOST_AUTO_TEST_CASE(auto_dimension_set) {
st.remove_maximal_simplex(st.find({1, 2, 3, 4}));
std::cout << "st.dimension()=" << st.dimension() << std::endl;
BOOST_CHECK(st.dimension() == 3);
- st.automatic_dimension_set();
+ st.downgrade_dimension();
std::cout << "st.dimension()=" << st.dimension() << std::endl;
BOOST_CHECK(st.dimension() == 2);
@@ -188,7 +188,7 @@ BOOST_AUTO_TEST_CASE(auto_dimension_set) {
st.remove_maximal_simplex(st.find({0, 1, 3, 4}));
std::cout << "st.dimension()=" << st.dimension() << std::endl;
BOOST_CHECK(st.dimension() == 3);
- st.automatic_dimension_set();
+ st.downgrade_dimension();
std::cout << "st.dimension()=" << st.dimension() << std::endl;
BOOST_CHECK(st.dimension() == 2);
@@ -208,9 +208,9 @@ BOOST_AUTO_TEST_CASE(auto_dimension_set) {
st.set_dimension(1);
std::cout << "st.dimension()=" << st.dimension() << std::endl;
BOOST_CHECK(st.dimension() == 1);
- st.automatic_dimension_set();
+ st.downgrade_dimension();
std::cout << "st.dimension()=" << st.dimension() << std::endl;
// check automatic_dimension_set() is not giving the rigt answer because dimension is too low
BOOST_CHECK(st.dimension() == 1);
@@ -219,9 +219,9 @@ BOOST_AUTO_TEST_CASE(auto_dimension_set) {
st.set_dimension(6);
std::cout << "st.dimension()=" << st.dimension() << std::endl;
BOOST_CHECK(st.dimension() == 6);
- st.automatic_dimension_set();
+ st.downgrade_dimension();
std::cout << "st.dimension()=" << st.dimension() << std::endl;
// check automatic_dimension_set() resets the correct dimension
BOOST_CHECK(st.dimension() == 3);
@@ -239,7 +239,7 @@ BOOST_AUTO_TEST_CASE(auto_dimension_set) {
st.remove_maximal_simplex(st.find({0, 1, 2, 3, 4, 5, 6}));
std::cout << "st.dimension()=" << st.dimension() << std::endl;
BOOST_CHECK(st.dimension() == 6);
- st.automatic_dimension_set();
+ st.downgrade_dimension();
std::cout << "st.dimension()=" << st.dimension() << std::endl;
BOOST_CHECK(st.dimension() == 5);
@@ -344,7 +344,7 @@ BOOST_AUTO_TEST_CASE(prune_above_filtration) {
std::cout << " - dimension " << st.dimension() << std::endl;
BOOST_CHECK(st.dimension() == 3);
- st.automatic_dimension_set();
+ st.downgrade_dimension();
std::cout << "dimension=" << st.dimension() << std::endl;
BOOST_CHECK(st.dimension() == -1);
@@ -208,9 +208,9 @@ BOOST_AUTO_TEST_CASE(auto_dimension_set) {
std::cout << "st.dimension()=" << st.dimension() << std::endl;
- // check automatic_dimension_set() is not giving the rigt answer because dimension is too low
+ // check downgrade_dimension() is not giving the rigt answer because dimension is too low
BOOST_CHECK(st.dimension() == 1);
@@ -219,9 +219,9 @@ BOOST_AUTO_TEST_CASE(auto_dimension_set) {
std::cout << "st.dimension()=" << st.dimension() << std::endl;
- // check automatic_dimension_set() resets the correct dimension
+ // check downgrade_dimension() resets the correct dimension
BOOST_CHECK(st.dimension() == 3);